==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/ActivityNodeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.ActionNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ActivityEdgeSet;
import io.ciera.tool.sql.ooaofooa.activity.ActivityNode;
import io.ciera.tool.sql.ooaofooa.activity.ActivityNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ControlNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ObjectNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.ActionNodeSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.ActivityEdgeSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.ControlNodeSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.ObjectNodeSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;

import java.util.Arrays;
import java.util.List;


public class ActivityNodeSetImpl extends InstanceSet<ActivityNodeSet,ActivityNode> implements ActivityNodeSet {

    // attributes
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ActivityNode activitynode : this ) activitynode.setId( ref_Id );
    }
    @Override
    public void setPackage_IDdeprecated( UniqueId m_Package_IDdeprecated ) throws XtumlException {
        for ( ActivityNode activitynode : this ) activitynode.setPackage_IDdeprecated( m_Package_IDdeprecated );
    }


    // selections
    @Override
    public ActivityEdgeSet R1103_incoming_ActivityEdge() throws XtumlException {
        ActivityEdgeSet activityedgeset = new ActivityEdgeSetImpl();
        for ( ActivityNode activitynode : this ) activityedgeset.addAll( activitynode.R1103_incoming_ActivityEdge() );
        return activityedgeset;
    }
    @Override
    public ActivityEdgeSet R1104_outgoing_ActivityEdge() throws XtumlException {
        ActivityEdgeSet activityedgeset = new ActivityEdgeSetImpl();
        for ( ActivityNode activitynode : this ) activityedgeset.addAll( activitynode.R1104_outgoing_ActivityEdge() );
        return activityedgeset;
    }
    @Override
    public ActionNodeSet R1105_is_a_ActionNode() throws XtumlException {
        ActionNodeSet actionnodeset = new ActionNodeSetImpl();
        for ( ActivityNode activitynode : this ) actionnodeset.add( activitynode.R1105_is_a_ActionNode() );
        return actionnodeset;
    }
    @Override
    public ControlNodeSet R1105_is_a_ControlNode() throws XtumlException {
        ControlNodeSet controlnodeset = new ControlNodeSetImpl();
        for ( ActivityNode activitynode : this ) controlnodeset.add( activitynode.R1105_is_a_ControlNode() );
        return controlnodeset;
    }
    @Override
    public ObjectNodeSet R1105_is_a_ObjectNode() throws XtumlException {
        ObjectNodeSet objectnodeset = new ObjectNodeSetImpl();
        for ( ActivityNode activitynode : this ) objectnodeset.add( activitynode.R1105_is_a_ObjectNode() );
        return objectnodeset;
    }
    @Override
    public PackageableElementSet R8001_is_a_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( ActivityNode activitynode : this ) packageableelementset.add( activitynode.R8001_is_a_PackageableElement() );
        return packageableelementset;
    }


    @Override
    public ActivityNode nullElement() {
        return ActivityNodeImpl.EMPTY_ACTIVITYNODE;
    }

    @Override
    public ActivityNodeSet emptySet() {
      return new ActivityNodeSetImpl();
    }

    @Override
    public ActivityNodeSet value() {
        return this;
    }

    @Override
    public List<ActivityNode> elements() {
        return Arrays.asList(toArray(new ActivityNode[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/activity/impl/ActivityNodeSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.activity.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.activity.ActionNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ActivityEdgeSet;
import io.ciera.tool.sql.ooaofooa.activity.ActivityNode;
import io.ciera.tool.sql.ooaofooa.activity.ActivityNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ControlNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.ObjectNodeSet;
import io.ciera.tool.sql.ooaofooa.activity.impl.ActionNodeSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.ActivityEdgeSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.ControlNodeSetImpl;
import io.ciera.tool.sql.ooaofooa.activity.impl.ObjectNodeSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ActivityNodeSetImpl extends InstanceSet<ActivityNodeSet,ActivityNode> implements ActivityNodeSet {

    public ActivityNodeSetImpl() {
    }

    public ActivityNodeSetImpl(Comparator<? super ActivityNode> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setPackage_IDdeprecated( UniqueId m_Package_IDdeprecated ) throws XtumlException {
        for ( ActivityNode activitynode : this ) activitynode.setPackage_IDdeprecated( m_Package_IDdeprecated );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( ActivityNode activitynode : this ) activitynode.setId( ref_Id );
    }


    // selections
    @Override
    public ActivityEdgeSet R1103_incoming_ActivityEdge() throws XtumlException {
        ActivityEdgeSet activityedgeset = new ActivityEdgeSetImpl();
        for ( ActivityNode activitynode : this ) activityedgeset.addAll( activitynode.R1103_incoming_ActivityEdge() );
        return activityedgeset;
    }
    @Override
    public ActivityEdgeSet R1104_outgoing_ActivityEdge() throws XtumlException {
        ActivityEdgeSet activityedgeset = new ActivityEdgeSetImpl();
        for ( ActivityNode activitynode : this ) activityedgeset.addAll( activitynode.R1104_outgoing_ActivityEdge() );
        return activityedgeset;
    }
    @Override
    public ActionNodeSet R1105_is_a_ActionNode() throws XtumlException {
        ActionNodeSet actionnodeset = new ActionNodeSetImpl();
        for ( ActivityNode activitynode : this ) actionnodeset.add( activitynode.R1105_is_a_ActionNode() );
        return actionnodeset;
    }
    @Override
    public ControlNodeSet R1105_is_a_ControlNode() throws XtumlException {
        ControlNodeSet controlnodeset = new ControlNodeSetImpl();
        for ( ActivityNode activitynode : this ) controlnodeset.add( activitynode.R1105_is_a_ControlNode() );
        return controlnodeset;
    }
    @Override
    public ObjectNodeSet R1105_is_a_ObjectNode() throws XtumlException {
        ObjectNodeSet objectnodeset = new ObjectNodeSetImpl();
        for ( ActivityNode activitynode : this ) objectnodeset.add( activitynode.R1105_is_a_ObjectNode() );
        return objectnodeset;
    }
    @Override
    public PackageableElementSet R8001_is_a_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( ActivityNode activitynode : this ) packageableelementset.add( activitynode.R8001_is_a_PackageableElement() );
        return packageableelementset;
    }


    @Override
    public ActivityNode nullElement() {
        return ActivityNodeImpl.EMPTY_ACTIVITYNODE;
    }

    @Override
    public ActivityNodeSet emptySet() {
      return new ActivityNodeSetImpl();
    }

    @Override
    public ActivityNodeSet emptySet(Comparator<? super ActivityNode> comp) {
      return new ActivityNodeSetImpl(comp);
    }

    @Override
    public ActivityNodeSet value() {
        return this;
    }

    @Override
    public List<ActivityNode> elements() {
        return Arrays.asList(toArray(new ActivityNode[0]));
    }

}
